@@ -21,7 +21,7 @@ import (
 // in place of the 'ssh' executable.
 const envShellSSH = "SSH"
 
-var shellHelp = `Execute shell in Lima
+const shellHelp = `Execute shell in Lima
 
 lima command is provided as an alias for limactl shell $LIMA_INSTANCE. $LIMA_INSTANCE defaults to "` + DefaultInstanceName + `".
 
@@ -32,7 +32,7 @@ Hint: try --debug to show the detailed logs, if it seems hanging (mostly due to
 `
 
 func newShellCommand() *cobra.Command {
-	var shellCmd = &cobra.Command{
+	shellCmd := &cobra.Command{
 		Use:               "shell [flags] INSTANCE [COMMAND...]",
 		Short:             "Execute shell in Lima",
 		Long:              shellHelp,
