@@ -157,7 +157,7 @@ func newQmpClient(cfg Config) (*qmp.SocketMonitor, error) {
 	return qmpClient, nil
 }
 
-func sendHmpCommand(cfg Config, cmd string, tag string) (string, error) {
+func sendHmpCommand(cfg Config, cmd, tag string) (string, error) {
 	qmpClient, err := newQmpClient(cfg)
 	if err != nil {
 		return "", err
@@ -313,7 +313,7 @@ type features struct {
 	VersionGEQ7 bool
 }
 
-func inspectFeatures(exe string, machine string) (*features, error) {
+func inspectFeatures(exe, machine string) (*features, error) {
 	var (
 		f      features
 		stdout bytes.Buffer
@@ -462,9 +462,9 @@ func qemuMachine(arch limayaml.Arch) string {
 	return "virt"
 }
 
-func Cmdline(cfg Config) (string, []string, error) {
+func Cmdline(cfg Config) (exe string, args []string, err error) {
 	y := cfg.LimaYAML
-	exe, args, err := Exe(*y.Arch)
+	exe, args, err = Exe(*y.Arch)
 	if err != nil {
 		return "", nil, err
 	}
@@ -569,12 +569,39 @@ func Cmdline(cfg Config) (string, []string, error) {
 		logrus.Warnf("field `firmware.legacyBIOS` is not supported for architecture %q, ignoring", *y.Arch)
 		legacyBIOS = false
 	}
-	if !legacyBIOS && *y.Arch != limayaml.RISCV64 {
-		firmware, err := getFirmware(exe, *y.Arch)
-		if err != nil {
-			return "", nil, err
+	if !legacyBIOS {
+		var firmware string
+		downloadedFirmware := filepath.Join(cfg.InstanceDir, filenames.QemuEfiCodeFD)
+		if _, stErr := os.Stat(downloadedFirmware); errors.Is(stErr, os.ErrNotExist) {
+		loop:
+			for _, f := range y.Firmware.Images {
+				switch f.VMType {
+				case "", limayaml.QEMU:
+					if f.Arch == *y.Arch {
+						if _, err = fileutils.DownloadFile(downloadedFirmware, f.File, true, "UEFI code "+f.Location, *y.Arch); err != nil {
+							logrus.WithError(err).Warnf("failed to download %q", f.Location)
+							continue loop
+						}
+						firmware = downloadedFirmware
+						logrus.Infof("Using firmware %q (downloaded from %q)", firmware, f.Location)
+						break loop
+					}
+				}
+			}
+		} else {
+			firmware = downloadedFirmware
+			logrus.Infof("Using existing firmware (%q)", firmware)
+		}
+		if firmware == "" && *y.Arch != limayaml.RISCV64 {
+			firmware, err = getFirmware(exe, *y.Arch)
+			if err != nil {
+				return "", nil, err
+			}
+			logrus.Infof("Using system firmware (%q)", firmware)
+		}
+		if firmware != "" {
+			args = append(args, "-drive", fmt.Sprintf("if=pflash,format=raw,readonly=on,file=%s", firmware))
 		}
-		args = append(args, "-drive", fmt.Sprintf("if=pflash,format=raw,readonly=on,file=%s", firmware))
 	}
 
 	// Disk
@@ -712,7 +739,7 @@ func Cmdline(cfg Config) (string, []string, error) {
 					args = append(args, "-netdev", fmt.Sprintf("socket,id=net%d,fd={{ fd_connect %q }}", i+1, sock))
 				} else if nwCfg.Paths.VDEVMNet != "" {
 					logrus.Warn("vdeVMNet is deprecated, use socketVMNet instead (See docs/network.md)")
-					vdeSock, err = networks.VDESock(nw.Lima)
+					vdeSock, err = networks.VDESock(nw.Lima) //nolint:staticcheck // deprecated
 					if err != nil {
 						return "", nil, err
 					}
@@ -1015,9 +1042,8 @@ func qemuArch(arch limayaml.Arch) string {
 	return arch
 }
 
-func Exe(arch limayaml.Arch) (string, []string, error) {
+func Exe(arch limayaml.Arch) (exe string, args []string, err error) {
 	exeBase := "qemu-system-" + qemuArch(arch)
-	var args []string
 	envK := "QEMU_SYSTEM_" + strings.ToUpper(qemuArch(arch))
 	if envV := os.Getenv(envK); envV != "" {
 		ss, err := shellwords.Parse(envV)
@@ -1029,7 +1055,7 @@ func Exe(arch limayaml.Arch) (string, []string, error) {
 			logrus.Warnf("Specifying args (%v) via $%s is supported only for debugging!", args, envK)
 		}
 	}
-	exe, err := exec.LookPath(exeBase)
+	exe, err = exec.LookPath(exeBase)
 	if err != nil {
 		return "", nil, err
 	}
